import { InsightRequest, ResponseCallback, WsFrontendCall, wsKeys, wsReturnKey, wsSubKeys } from 'ts-common';
import { Broker } from './broker';

export const wsGetInsights: WsFrontendCall<{ saveStateId: string }, wsReturnKey.insightResults> = (params, callback) => {
  Broker.instance().sendMessage(
    {
      key: wsKeys.insight,
      subKey: wsSubKeys.getAll,
      body: { saveStateId: params.saveStateId },
    },
    callback,
  );
};

export const wsCreateInsight: WsFrontendCall<InsightRequest, wsReturnKey.insightResult> = (params, callback) => {
  Broker.instance().sendMessage<wsReturnKey.insightResult>(
    {
      key: wsKeys.insight,
      subKey: wsSubKeys.create,
      body: params,
    },
    params => {
      if (params.status === 'Bad Request') {
        console.error('Failed to create insight:', params.data);
        if (callback) callback(params);
        return;
      }

      if (!params.data || typeof params.data !== 'object') {
        console.error('Invalid response data', params.data);
        return;
      }

      if (!params.data.type || !params.data.id) {
        console.error('Missing fields in response', params.data);
        return;
      }

      if (callback) callback(params);
    },
  );
};

export const wsUpdateInsight: WsFrontendCall<{ id: number; insight: InsightRequest; generateEmail: boolean }, wsReturnKey.insightResult> = (
  params,
  callback,
) => {
  Broker.instance().sendMessage<wsReturnKey.insightResult>(
    {
      key: wsKeys.insight,
      subKey: wsSubKeys.update,
      body: { id: params.id, insight: params.insight, generateEmail: params.generateEmail },
    },
    params => {
      if (params.status === 'Bad Request') {
        console.error('Failed to update insight:', params.data);
      }
      if (callback) callback(params);
    },
  );
};

export const wsDeleteInsight: WsFrontendCall<{ id: number }, wsReturnKey.insightResult> = (params, callback) => {
  Broker.instance().sendMessage<wsReturnKey.insightResult>(
    {
      key: wsKeys.insight,
      subKey: wsSubKeys.delete,
      body: { id: params.id },
    },
    params => {
      if (params.status === 'Bad Request') {
        console.error('Failed to delete insight:', params.data);
      }
      if (callback) callback(params);
    },
  );
};

export function wsInsightSubscription(callback: ResponseCallback<wsReturnKey.insightResult>) {
  const id = Broker.instance().subscribe(callback, wsReturnKey.insightResult);
  return () => {
    Broker.instance().unSubscribe(wsReturnKey.insightResult, id);
  };
}
