import { configureStore } from '@reduxjs/toolkit';
import policyPermissionSlice from './authorizationResourcesSlice';
import policyUsersSlice from './authorizationUsersSlice';
import authSlice from './authSlice';
import configSlice from './configSlice';
import graphQuerySlice from './graphQuerySlice';
import insightSharingSlice from './insightSharingSlice';
import interactionSlice from './interactionSlice';
import mlSlice from './mlSlice';
import projectSlice from './projectSlice';
import schemaSlice from './schemaSlice';
import searchResultSlice from './searchResultSlice';
import sessionSlice from './sessionSlice';
import visualizationSlice from './visualizationSlice';

export const store = configureStore({
  reducer: {
    graphQuery: graphQuerySlice,
    schema: schemaSlice,
    sessionCache: sessionSlice,
    auth: authSlice,
    config: configSlice,
    ml: mlSlice,
    searchResults: searchResultSlice,
    interaction: interactionSlice,
    visualize: visualizationSlice,
    policyUsers: policyUsersSlice,
    policyResources: policyPermissionSlice,
    insightSharing: insightSharingSlice,
    project: projectSlice,
  },
  middleware: getDefaultMiddleware =>
    getDefaultMiddleware({
      serializableCheck: {
        ignoredPaths: ['schema.graphologySerialized', 'querybuilder.graphologySerialized'],
      },
    }),
});

// Infer the `RootState` and `AppDispatch` types from the store itself
export type RootState = ReturnType<typeof store.getState>;
// Inferred type: {counter: CounterState}
export type AppDispatch = typeof store.dispatch;
