import {
  AllLayoutAlgorithms,
  CytoscapeLayoutAlgorithms,
  GraphologyLayoutAlgorithms,
  ListLayoutAlgorithms,
} from 'ts-common/src/model/layouts';
import { CytoscapeLayout, CytoscapeLayouts, CytoscapeProvider } from './cytoscapeLayouts';
import { DagreLayout, DagreLayouts, DagreProvider } from './dagreLayout';
import { GraphologyLayout, GraphologyLayouts, GraphologyProvider } from './graphologyLayouts';
import { ListLayout, ListLayoutProvider, ListLayouts } from './listLayouts';

export type Providers = GraphologyProvider | CytoscapeProvider | ListLayoutProvider | DagreProvider;
export type LayoutAlgorithm<Provider extends Providers> = `${Provider}_${string}`;

export type AlgorithmToLayoutProvider<Algorithm extends AllLayoutAlgorithms = AllLayoutAlgorithms> =
  Algorithm extends GraphologyLayoutAlgorithms
    ? GraphologyLayout
    : Algorithm extends CytoscapeLayoutAlgorithms
      ? CytoscapeLayout
      : Algorithm extends ListLayoutAlgorithms
        ? ListLayout
        : DagreLayout;

export const Layouts = {
  ...GraphologyLayouts,
  ...CytoscapeLayouts,
  ...ListLayouts,
  ...DagreLayouts,
} as const;

export type LayoutTypes = (typeof Layouts)[keyof typeof Layouts];
