import { useActiveQuery, useGraphQuery, useSessionCache } from '@/lib/data-access';
import { Button } from '../../components';

export function NoData() {
  const activeQuery = useActiveQuery();
  const session = useSessionCache();
  const graph = useGraphQuery();
  const dataAvailable = !activeQuery || activeQuery.graph.nodes.length > 0;

  return (
    <div className="flex justify-center items-center h-full">
      <div className="max-w-lg mx-auto text-left">
        {graph.status === 'error' ? (
          <div className="m-3 self-center text-center flex h-full flex-col justify-center">
            <p className="text-xl font-bold text-error">An error occurred while fetching data!</p>
            <p className="">Please retry or contact your Database's Administrator</p>
          </div>
        ) : graph.status === 'aborted' ? (
          <div className="m-3 self-center text-center flex h-full flex-col justify-center">
            <p className="text-xl font-bold text-error">Your query was aborted</p>
            <p className="">Please retry or contact your Database's Administrator</p>
          </div>
        ) : !session.currentSaveState ? (
          <p>
            <span>No database selected. </span>
            <span>Please select a database using the database selector on the top left of your screen.</span>
          </p>
        ) : dataAvailable ? (
          <div>
            <p className="text-xl font-normal text-secondary-600">No data available to be shown</p>
            <p>Query resulted in empty dataset</p>
          </div>
        ) : (
          <div>
            <p className="text-xl font-normal text-secondary-600">No data available to be shown</p>
            <p>Query for data to visualize</p>
            <Button
              variantType="primary"
              variant="outline"
              label="Learn how to query data"
              size="sm"
              iconComponent="icon-[ic--outline-info]"
              onClick={() => window.open('https://graphpolaris.com', '_blank')}
            />
          </div>
        )}
      </div>
    </div>
  );
}
