import { useMemo } from 'react';
import { NodeQueryResult } from 'ts-common';
import { Coordinate, LocationInfo } from '../mapvis.types';

export const useCoordinateLookup = (nodes: NodeQueryResult[], locationSettings: Record<string, LocationInfo>) => {
  return useMemo(() => {
    return nodes.reduce(
      (acc, node) => {
        const latitude = locationSettings?.[node.label]?.lat
          ? (node?.attributes?.[locationSettings[node.label].lat as any] as string)
          : undefined;
        const longitude = locationSettings?.[node.label]?.lon
          ? (node?.attributes?.[locationSettings[node.label].lon as any] as string)
          : undefined;

        if (latitude !== undefined && longitude !== undefined) {
          acc[node._id] = [parseFloat(longitude), parseFloat(latitude)];
        }

        return acc;
      },
      {} as { [id: string]: Coordinate },
    );
  }, [nodes, locationSettings]);
};
