import { ML } from 'ts-common';
import { EdgeType, GraphType } from '../../types';
import { nodeColor } from '../utils';
import { LINE_COLOR_ML } from './edgeStyle';

export function processLinkPrediction(ml: ML, graph: GraphType): GraphType {
  if (ml === undefined || ml.linkPrediction === undefined || !ml.linkPrediction.enabled) return graph;

  if (ml.linkPrediction.enabled) {
    const nodeIds = new Set(Object.keys(graph.nodeIdMap));
    ml.linkPrediction.result.forEach(edge => {
      if (nodeIds.has(edge.from) && nodeIds.has(edge.to)) {
        const toAdd: EdgeType = {
          id: edge.from + ':LP:' + edge.to, // TODO: this only supports one link between two nodes
          ids: [],
          source: graph.nodeIdMap[edge.from],
          target: graph.nodeIdMap[edge.to],
          label: 'prediction',
          color: LINE_COLOR_ML,
          style: 1,
          thickness: edge.attributes.jaccard_coefficient,
          alpha: 1,
        };
        graph.edges[toAdd.id] = toAdd;
      }
    });
  }
  return graph;
}

export function processCommunityDetection(ml: ML, graph: GraphType): GraphType {
  if (ml === undefined || ml.communityDetection === undefined || !ml.communityDetection.enabled) return graph;

  console.log('processCommunityDetection', ml.communityDetection);
  if (ml.communityDetection.enabled) {
    const nodeToColorId = new Map<string, number>();
    ml.communityDetection.result.forEach((idSet, i) => {
      idSet.forEach(id => {
        nodeToColorId.set(id, i);
      });
    });

    Object.keys(graph.nodes).forEach(nodeId => {
      if (nodeToColorId.has(nodeId)) {
        graph.nodes[nodeId].color = nodeColor(nodeToColorId.get(nodeId) ?? 0);
      } else {
        graph.nodes[nodeId].color = nodeColor(-1);
      }
    });
  } else {
    Object.keys(graph.nodes).forEach(nodeId => {
      graph.nodes[nodeId].color = nodeColor(-1);
    });
  }
  return graph;
}

export function processML(ml: ML, graph: GraphType): GraphType {
  let ret = processLinkPrediction(ml, graph);
  ret = processCommunityDetection(ml, ret);
  return ret;
}
