import { visualizationColors } from '@/config';

/**
 * Colour is a function that takes a string of a number and returns a number of a color out of the d3 color scheme.
 * @param num Num is the input string representing a number of a colorgroup.
 * @returns {number} A number corresponding to a color in the d3 color scheme.
 */
export function nodeColor(num: number): number {
  return binaryColor(nodeColorHex(num));
}

export function nodeColorHex(num: number) {
  // num = num % 4;
  // const col = '#000000';

  //let entityColors = Object.values(visualizationColors.GPSeq.colors[9]);
  const colors = visualizationColors.GPCat.colors[14];
  const index = (((num - 1) % colors.length) + colors.length) % colors.length; // wrap around numbers
  const col = colors[index];
  return col;
}

export function binaryColor(color: string) {
  return Number('0x' + color.replace('#', ''));
}

export function hexColorFromBinary(num: number) {
  const hex = num.toString(16);
  return '#' + hex.padStart(6, '0');
}

export function uniq<T>(items: T[]): T[] {
  return Array.from(new Set<T>(items));
}

/**
 * Converts a hexadecimal color code to a number.
 *
 * @param hexColor The hexadecimal color code to convert.
 * @returns The converted number.
 */
export function hexToNumber(hexColor: string) {
  return parseInt(hexColor.replace('#', ''), 16);
}

export function hslStringToHex(hsl: string) {
  // Extract h, s, l from the input string

  const match = hsl.match(/\d+/g);
  if (!match) return '#000000';
  const [h, s, lConst] = match.map(Number);

  let l = lConst;
  l /= 100;
  const a = (s * Math.min(l, 1 - l)) / 100;
  const f = (n: number) => {
    const k = (n + h / 30) % 12;
    const color = l - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
    return Math.round(255 * color)
      .toString(16)
      .padStart(2, '0'); // Convert to Hex and ensure 2 digits
  };
  return `#${f(0)}${f(8)}${f(4)}`;
}
